@@ -1,10 +1,10 @@
 #!/usr/bin/python3
 # -*- coding: utf-8 -*-
 
-"""Shows all times of day for the given timezones.
+"""Shows all times of day for the given time zones.
 
 This can be useful to select a common meeting time across multiple
-timezones easily. This takes into account daylight savings and
+time zones easily. This takes into account daylight savings and
 whatnot, and can schedule meetings in the future. Default settings are
 taken from ~/.config/undertime.yml. Dates are parsed with the
 dateparser or parsedatetime modules, if available, in that order, see
@@ -42,7 +42,7 @@ import termcolor
 
 try:
     import dateparser
-except ImportError:
+except ImportError:  # pragma: no cover
     dateparser = None
     try:
         import parsedatetime
@@ -51,8 +51,8 @@ except ImportError:
 
 from dateutil.relativedelta import relativedelta
 
-# XXX: we *also* need pytz even though dateutil also ships timezone
-# info. pytz has the *list* of all timezones, which dateutil doesn't
+# XXX: we *also* need pytz even though dateutil also ships time zone
+# info. pytz has the *list* of all time zones, which dateutil doesn't
 # ship, or at least not yet. This might eventually all get fixed in
 # the standard library, see:
 # https://lwn.net/SubscriberLink/813691/8d2dde9efd443c3b/
@@ -136,7 +136,7 @@ class ConfigAction(argparse.Action):
             if config:
                 parser.set_defaults(**config)
 
-    def parse_config(self, path):
+    def parse_config(self, path):  # pragma: no cover
         """abstract implementation of config file parsing, should be overriden in subclasses"""
         raise NotImplementedError()
 
@@ -229,27 +229,29 @@ class UndertimeArgumentParser(ConfigArgumentParser):
             description="pick a meeting time", epilog=__doc__, *args, **kwargs
         )
         self.add_argument(
-            "timezones", nargs="*", help="timezones to show [default: current timezone]"
+            "timezones",
+            nargs="*",
+            help="time zones to show [default: current time zone]",
         )
         self.add_argument(
-            "--start",
             "-s",
+            "--start",
             default=9,
             type=int,
             metavar="HOUR",
             help="start of working day, in hours [default: %(default)s]",
         )
         self.add_argument(
-            "--end",
             "-e",
+            "--end",
             default=17,
             type=int,
             metavar="HOUR",
             help="end of working day, in hours [default: %(default)s]",
         )
         self.add_argument(
-            "--date",
             "-d",
+            "--date",
             default=None,
             metavar="WHEN",
             help='target date for the meeting, for example "in two weeks" [default: now]',
@@ -267,21 +269,21 @@ class UndertimeArgumentParser(ConfigArgumentParser):
             "--default-zone",
             action=NegateAction,
             dest="default_zone",
-            help="show current timezone first [default: %(default)s]",
+            help="show current time zone first [default: %(default)s]",
         )
         self.add_argument(
             "--no-unique",
             "--unique",
             action=NegateAction,
             dest="unique",
-            help="deduplicate timezone offsets [default: %(default)s]",
+            help="deduplicate time zone offsets [default: %(default)s]",
         )
         self.add_argument(
             "--no-overlap",
             "--overlap",
             action=NegateAction,
             dest="overlap_show",
-            help='show zones overlap in column "n" [default: %(default)s]',
+            help="show zones overlap [default: %(default)s]",
         )
         self.add_argument(
             "--overlap-min",
@@ -291,8 +293,15 @@ class UndertimeArgumentParser(ConfigArgumentParser):
             help="minimum overlap between zones [default: %(default)s]",
         )
         self.add_argument(
-            "--format",
+            "--abbreviate",
+            "--no-abbreviate",
+            dest="abbreviate",
+            action=NegateAction,
+            help="short column headers [default: %(default)s]",
+        )
+        self.add_argument(
             "-f",
+            "--format",
             default="fancy_grid_nogap",
             choices=tabulate.tabulate_formats + ["fancy_grid_nogap"],
             help="output format (%(default)s)",
@@ -314,16 +323,19 @@ class UndertimeArgumentParser(ConfigArgumentParser):
             help="enable debugging messages",
         )
         self.add_argument(
-            "--list-zones",
             "-l",
+            "--list-zones",
             action="store_true",
-            help="show valid timezones and exit",
+            help="show valid time zones and exit",
         )
         self.add_argument(
             "--selftest", action="store_true", help="run test suite and exit"
         )
         self.add_argument(
-            "--version", action=ImportlibVersionAction, help="print version number and exit"
+            "-V",
+            "--version",
+            action=ImportlibVersionAction,
+            help="print version number and exit",
         )
 
 
@@ -385,7 +397,8 @@ class OffsetZone(pytz._FixedOffset):
             hours = int(match.group("hours"))
             if strmin is not None:
                 minutes = int(strmin)
-        except ValueError as e:
+        except ValueError as e:  # pragma: no cover
+            # this probably will never get triggered because of the regex
             raise ValueError("Invalid offset: %s, skipping zone: %s" % (e, zone))
 
         assert hours >= 0
@@ -396,7 +409,7 @@ class OffsetZone(pytz._FixedOffset):
             raise ValueError("Minute cannot be bigger than 59: %s" % minutes)
 
         total = hours * 60 + minutes
-        if sign == '-':
+        if sign == "-":
             total *= -1
 
         self._zone = zone
@@ -449,7 +462,7 @@ def parse_date(date, local_zone):
             date,
             settings={"TIMEZONE": str(local_zone), "RETURN_AS_TIMEZONE_AWARE": True},
         )
-    elif parsedatetime:
+    elif parsedatetime:  # pragma: no cover
         logging.debug("parsing date with parsedatetime module")
         cal = parsedatetime.Calendar()
         now, parse_status = cal.parseDT(datetimeString=date, tzinfo=local_zone)
@@ -467,7 +480,7 @@ def flush_logging_handlers():
     This is used in the test suite."""
     for handler in logging.getLogger().handlers:
         # BufferingHandler or pytest.LogCaptureHandler
-        buffer = getattr(handler, "buffer", None) or getattr(handler, "records", None)
+        buffer = getattr(handler, "buffer", []) or getattr(handler, "records", [])
         # too bad that is necessary, seems to me pytest should have
         # implemented a BufferingHandler as well...
 
@@ -490,41 +503,57 @@ def main(args):
     >>> zones = ['EST', 'US/Eastern', 'UTC']
     >>> args = UndertimeArgumentParser().parse_args(argv + date + zones)
     >>> main(args)
-    ╔════════╤══════════════╤════════╤═════╗
-    ║  EST   │  US/Eastern  │  UTC   │   n ║
-    ╠════════╪══════════════╪════════╪═════╣
-    ║ 19:00  │    19:00     │ 00:00  │   0 ║
-    ║ 20:00  │    20:00     │ 01:00  │   0 ║
-    ║ 21:00  │    21:00     │ 02:00  │   0 ║
-    ║ 22:00  │    22:00     │ 03:00  │   0 ║
-    ║ 23:00  │    23:00     │ 04:00  │   0 ║
-    ║ 00:00  │    00:00     │ 05:00  │   0 ║
-    ║ 01:00  │    01:00     │ 06:00  │   0 ║
-    ║ 02:00  │    03:00     │ 07:00  │   0 ║
-    ║ 03:00  │    04:00     │ 08:00  │   0 ║
-    ║ 04:00  │    05:00     │ 09:00_ │   1 ║
+    ╔════════╤══════════════╤════════╤═══════════╗
+    ║  EST   │  US/Eastern  │  UTC   │   overlap ║
+    ╠════════╪══════════════╪════════╪═══════════╣
+    ║ 19:00  │    19:00     │ 00:00  │         0 ║
+    ║ 20:00  │    20:00     │ 01:00  │         0 ║
+    ║ 21:00  │    21:00     │ 02:00  │         0 ║
+    ║ 22:00  │    22:00     │ 03:00  │         0 ║
+    ║ 23:00  │    23:00     │ 04:00  │         0 ║
+    ║ 00:00  │    00:00     │ 05:00  │         0 ║
+    ║ 01:00  │    01:00     │ 06:00  │         0 ║
+    ║ 02:00  │    03:00     │ 07:00  │         0 ║
+    ║ 03:00  │    04:00     │ 08:00  │         0 ║
+    ║ 04:00  │    05:00     │ 09:00_ │         1 ║
     ...
     Local time requested: 2020-03-08 16:00:00+00:00
     Equivalent to: 11:00 EST, 12:00 US/Eastern, 16:00 UTC
     >>> date = ['--date', '2020-11-01 12:00:00-04:00']
     >>> args = UndertimeArgumentParser().parse_args(argv + date + zones)
     >>> main(args)
-    ╔════════╤══════════════╤════════╤═════╗
-    ║  EST   │  US/Eastern  │  UTC   │   n ║
-    ╠════════╪══════════════╪════════╪═════╣
-    ║ 19:00  │    20:00     │ 00:00  │   0 ║
-    ║ 20:00  │    21:00     │ 01:00  │   0 ║
-    ║ 21:00  │    22:00     │ 02:00  │   0 ║
-    ║ 22:00  │    23:00     │ 03:00  │   0 ║
-    ║ 23:00  │    00:00     │ 04:00  │   0 ║
-    ║ 00:00  │    01:00     │ 05:00  │   0 ║
-    ║ 01:00  │    01:00     │ 06:00  │   0 ║
-    ║ 02:00  │    02:00     │ 07:00  │   0 ║
-    ║ 03:00  │    03:00     │ 08:00  │   0 ║
-    ║ 04:00  │    04:00     │ 09:00_ │   1 ║
+    ╔════════╤══════════════╤════════╤═══════════╗
+    ║  EST   │  US/Eastern  │  UTC   │   overlap ║
+    ╠════════╪══════════════╪════════╪═══════════╣
+    ║ 19:00  │    20:00     │ 00:00  │         0 ║
+    ║ 20:00  │    21:00     │ 01:00  │         0 ║
+    ║ 21:00  │    22:00     │ 02:00  │         0 ║
+    ║ 22:00  │    23:00     │ 03:00  │         0 ║
+    ║ 23:00  │    00:00     │ 04:00  │         0 ║
+    ║ 00:00  │    01:00     │ 05:00  │         0 ║
+    ║ 01:00  │    01:00     │ 06:00  │         0 ║
+    ║ 02:00  │    02:00     │ 07:00  │         0 ║
+    ║ 03:00  │    03:00     │ 08:00  │         0 ║
+    ║ 04:00  │    04:00     │ 09:00_ │         1 ║
     ...
     Local time requested: 2020-11-01 16:00:00+00:00
     Equivalent to: 11:00 EST, 11:00 US/Eastern, 16:00 UTC
+    >>> extra = [ '--no-overlap', '--abbreviate' ]
+    >>> args = UndertimeArgumentParser().parse_args(argv + date + zones + extra)
+    >>> main(args)
+    ╔════════╤═══════════╤════════╗
+    ║  EST   │  Eastern  │  UTC   ║
+    ╠════════╪═══════════╪════════╣
+    ║ 19:00  │   20:00   │ 00:00  ║
+    ...
+    >>> extra = [ '--overlap', '--abbreviate' ]
+    >>> args = UndertimeArgumentParser().parse_args(argv + date + zones + extra)
+    >>> main(args)
+    ╔════════╤═══════════╤════════╤═════╗
+    ║  EST   │  Eastern  │  UTC   │   n ║
+    ╠════════╪═══════════╪════════╪═════╣
+    ║ 19:00  │   20:00   │ 00:00  │   0 ║
+    ...
     >>> logging.getLogger('').setLevel('WARNING')
     >>> argv = ['--config', '/dev/null', '--no-default']
     >>> args = UndertimeArgumentParser().parse_args(argv + date + [ 'CEST' ])
@@ -532,9 +561,19 @@ def main(args):
     Traceback (most recent call last):
         ...
     SystemExit: 1
-    >>> print("\\n".join(flush_logging_handlers()))
-    unknown zone, skipping: CEST
-    No valid timezone found.
+    >>> msgs = flush_logging_handlers()
+    >>> assert 'unknown zone, skipping: CEST' in msgs
+    >>> assert 'No valid time zone found.' in msgs
+    >>> args = UndertimeArgumentParser().parse_args(argv + ['--list-zones'])
+    >>> main(args)
+    Africa/Abidjan
+    ...
+    Zulu
+    >>> args = UndertimeArgumentParser().parse_args(argv + ['--version'])
+    Traceback (most recent call last):
+        ...
+    SystemExit: 0
+    >>>
     """
     if args.list_zones:
         print("\n".join(pytz.all_timezones))
@@ -546,14 +585,14 @@ def main(args):
 
     # get the current UTC time
     now_utc = datetime.datetime.now(datetime.timezone.utc)
-    # ... to extract the local system's timezone
+    # ... to extract the local system's time zone
     # https://stackoverflow.com/a/39079819/1174784
     now_zone = now_utc.astimezone().tzinfo
-    # make an educated guess at what the user meant by passing that timezone to parse_date
+    # make an educated guess at what the user meant by passing that time zone to parse_date
     then_local = parse_date(args.date, now_zone).replace(second=0, microsecond=0)
     # convert that time to UTC again
     then_utc = then_local.astimezone(datetime.timezone.utc)
-    # and guess what timezone that was *then*
+    # and guess what time zone that was *then*
     then_zone = then_utc.astimezone().tzinfo
 
     timezones = []
@@ -564,7 +603,7 @@ def main(args):
         timezones = list(uniq_zones(timezones, then_utc))
 
     if not timezones:
-        logging.error("No valid timezone found.")
+        logging.error("No valid time zone found.")
         sys.exit(1)
 
     rows = compute_table(
@@ -574,6 +613,7 @@ def main(args):
         args.end,
         overlap_min=args.overlap_min,
         overlap_show=args.overlap_show,
+        abbreviate=args.abbreviate,
     )
     # reproduce the terminaltables DoubleTable output in tabulate:
     # https://github.com/cmck/python-tabulate/issues/1
@@ -597,6 +637,7 @@ def main(args):
         times.append(
             "{0:%H:%M} {1}".format(then_local.astimezone(tz=zone).timetz(), zone)
         )
+    print("UTC time requested: {}".format(then_utc))
     print("Local time requested: {}".format(then_local))
     print("Equivalent to: " + ", ".join(times))
 
@@ -619,8 +660,9 @@ def guess_zone(zone):
     'UTC-4'
     >>> guess_zone("UTC-X") is None
     True
-    >>> print("\\n".join(flush_logging_handlers()))
-    unknown zone, skipping: UTC-X
+    >>> assert 'unknown zone, skipping: UTC-X' in flush_logging_handlers()
+    >>> guess_zone("UTC-25") is None
+    True
     """
     try:
         return OffsetZone(zone)
@@ -645,6 +687,15 @@ def guess_zone(zone):
 
 
 def uniq_zones(timezones, now):
+    """uniquify time zones provided, based on the given current time
+
+    >>> local_zone = datetime.timezone(datetime.timedelta(days=-1, seconds=72000), 'EDT')
+    >>> now = parse_date('2020-03-08 22:30', local_zone=local_zone)
+    >>> zones = [guess_zone('Toronto'), guess_zone('Canada/Eastern')]
+    >>> list(uniq_zones(zones, now))
+    [<DstTzInfo 'America/Toronto' LMT-1 day, 18:42:00 STD>]
+    """
+    # XXX: what does this do again?
     now = now.replace(tzinfo=None)
     offsets = set()
     for zone in timezones:
@@ -662,7 +713,9 @@ def uniq_zones(timezones, now):
             yield zone
 
 
-def compute_table(now_local, timezones, start, end, overlap_min=0, overlap_show=True):
+def compute_table(
+    now_local, timezones, start, end, overlap_min=0, overlap_show=True, abbreviate=False
+):
     """
     >>> local_zone = datetime.timezone(datetime.timedelta(days=-1, seconds=72000), 'EDT')
     >>> now = parse_date('2020-03-08 22:30', local_zone=local_zone)
@@ -696,12 +749,22 @@ def compute_table(now_local, timezones, start, end, overlap_min=0, overlap_show=
     # the table is a list of rows, which are themselves a list of cells
     rows = []
 
-    # the first line is the list of timezones
+    # the first line is the list of time zones
     line = []
     for t in timezones:
-        line.append(str(t))
+        if abbreviate:
+            try:
+                prefix, suffix = str(t).split("/", 1)
+            except ValueError:
+                suffix = str(t)
+            line.append(suffix)
+        else:
+            line.append(str(t))
     if overlap_show:
-        line.append("n")
+        if abbreviate:
+            line.append("n")
+        else:
+            line.append("overlap")
     rows.append(line)
 
     while current_time < start_time + relativedelta(hours=+24):
@@ -729,7 +792,7 @@ def compute_table(now_local, timezones, start, end, overlap_min=0, overlap_show=
     return rows
 
 
-if __name__ == "__main__":
+if __name__ == "__main__":  # pragma: nocover
     logging.basicConfig(format="%(levelname)s: %(message)s", level="WARNING")
     parser = UndertimeArgumentParser()
     args = parser.parse_args()
@@ -746,7 +809,7 @@ if __name__ == "__main__":
         # stream handlers here, we need to use a BufferingHandler and
         # manually check it.
         logging.getLogger().addHandler(logging.handlers.BufferingHandler(10))
-        # tests are designed to run with a UTC timezone
+        # tests are designed to run with a UTC time zone
         os.environ["TZ"] = "UTC"
         import doctest
 
